Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(456)

Unified Diff: net/spdy/hpack/hpack_input_stream_test.cc

Issue 1535363003: Switch to standard integer types in net/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: stddef Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/spdy/hpack/hpack_input_stream.cc ('k') | net/spdy/hpack/hpack_output_stream.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/spdy/hpack/hpack_input_stream_test.cc
diff --git a/net/spdy/hpack/hpack_input_stream_test.cc b/net/spdy/hpack/hpack_input_stream_test.cc
index 3468516adedaa8c37d991f790ec5a7e0f6995ed4..6c4108f451c46c56e26362adb7dc37aa5e884645 100644
--- a/net/spdy/hpack/hpack_input_stream_test.cc
+++ b/net/spdy/hpack/hpack_input_stream_test.cc
@@ -45,30 +45,30 @@ const char kEncodedHuffmanFixture[] =
const char kDecodedHuffmanFixture[] =
"foo=ASDJKHQKBZXOQWEOPIUAXQWEOIU; max-age=3600; version=1";
// Utility function to decode an assumed-valid uint32 with an N-bit
// prefix.
-uint32 DecodeValidUint32(uint8 N, StringPiece str) {
+uint32_t DecodeValidUint32(uint8_t N, StringPiece str) {
EXPECT_GT(N, 0);
EXPECT_LE(N, 8);
HpackInputStream input_stream(kLiteralBound, str);
input_stream.SetBitOffsetForTest(8 - N);
- uint32 I;
+ uint32_t I;
EXPECT_TRUE(input_stream.DecodeNextUint32(&I));
return I;
}
// Utility function to decode an assumed-invalid uint32 with an N-bit
// prefix.
-void ExpectDecodeUint32Invalid(uint8 N, StringPiece str) {
+void ExpectDecodeUint32Invalid(uint8_t N, StringPiece str) {
EXPECT_GT(N, 0);
EXPECT_LE(N, 8);
HpackInputStream input_stream(kLiteralBound, str);
input_stream.SetBitOffsetForTest(8 - N);
- uint32 I;
+ uint32_t I;
EXPECT_FALSE(input_stream.DecodeNextUint32(&I));
}
-uint32 bits32(const string& bitstring) {
+uint32_t bits32(const string& bitstring) {
return std::bitset<32>(bitstring).to_ulong();
}
@@ -147,7 +147,7 @@ TEST_F(HpackInputStreamTest, SixByteIntegersEightBitPrefix) {
ExpectDecodeUint32Invalid(8, "\xff\xff\xff\xff\xff\xff");
}
// There are no valid uint32 encodings that are greater than six
// bytes.
TEST_F(HpackInputStreamTest, SevenByteIntegersEightBitPrefix) {
ExpectDecodeUint32Invalid(8, "\xff\x80\x80\x80\x80\x80\x00");
@@ -459,7 +459,7 @@ TEST_F(HpackInputStreamTest, SixByteIntegersOneToSevenBitPrefixes) {
ExpectDecodeUint32Invalid(1, "\xff\xfe\xff\xff\xff\xff");
}
// There are no valid uint32 encodings that are greater than six
// bytes.
TEST_F(HpackInputStreamTest, SevenByteIntegersOneToSevenBitPrefixes) {
ExpectDecodeUint32Invalid(7, "\x7f\x80\x80\x80\x80\x80\x00");
@@ -550,7 +550,7 @@ TEST_F(HpackInputStreamTest, DecodeNextHuffmanStringNotEnoughInput) {
TEST_F(HpackInputStreamTest, PeekBitsAndConsume) {
HpackInputStream input_stream(kLiteralBound, "\xad\xab\xad\xab\xad");
- uint32 bits = 0;
+ uint32_t bits = 0;
size_t peeked_count = 0;
// Read 0xad.
« no previous file with comments | « net/spdy/hpack/hpack_input_stream.cc ('k') | net/spdy/hpack/hpack_output_stream.h » ('j') | no next file with comments »
@@ -45,30 +45,30 @@ const char kEncodedHuffmanFixture[] =
const char kDecodedHuffmanFixture[] =
"foo=ASDJKHQKBZXOQWEOPIUAXQWEOIU; max-age=3600; version=1";
-// Utility function to decode an assumed-valid uint32 with an N-bit
+// Utility function to decode an assumed-valid uint32_t with an N-bit
// prefix.
@@ -45,30 +45,30 @@ const char kEncodedHuffmanFixture[] =
return I;
}
-// Utility function to decode an assumed-invalid uint32 with an N-bit
+// Utility function to decode an assumed-invalid uint32_t with an N-bit
// prefix.
@@ -147,7 +147,7 @@ TEST_F(HpackInputStreamTest, SixByteIntegersEightBitPrefix) {
ExpectDecodeUint32Invalid(8, "\xff\xff\xff\xff\xff\xff");
}
-// There are no valid uint32 encodings that are greater than six
+// There are no valid uint32_t encodings that are greater than six
// bytes.
TEST_F(HpackInputStreamTest, SevenByteIntegersEightBitPrefix) {
@@ -459,7 +459,7 @@ TEST_F(HpackInputStreamTest, SixByteIntegersOneToSevenBitPrefixes) {
ExpectDecodeUint32Invalid(1, "\xff\xfe\xff\xff\xff\xff");
}
-// There are no valid uint32 encodings that are greater than six
+// There are no valid uint32_t encodings that are greater than six
// bytes.
TEST_F(HpackInputStreamTest, SevenByteIntegersOneToSevenBitPrefixes) {

Powered by Google App Engine
This is Rietveld 408576698